/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
import { IDownloadRseOptions } from './doc/IDownloadRseOptions';
/**
 * This class holds helper functions that are used to download data sets, members and more through the RSE APIs
 */
export declare class Download {
    /**
     * Retrieve data sets and/or members contents and save them in your local workspace
     *
     * @param {Session}          session      - RSE connection info
     * @param {string}           dataSetName  - contains the data set name
     * @param {IDownloadOptions} [options={}] - contains the options to be sent
     * @param {string}           mappingsFile - an absolute path to a conversion mappings file
     *
     * @returns {Promise<IZosFilesResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} data set name must be set
     * @throws {Error} When the {@link RseRestClient} throws an error
     *
     * @example
     * ```typescript
     *
     * // Download "USER.DATA.SET.PS" to "user/data/set/ps.txt"
     * await Download.dataSet(session, "USER.DATA.SET.PS");
     *
     * // Download "USER.DATA.SET.PDS(MEMBER)" to "user/data/set/pds/member.txt"
     * await Download.dataSet(session, "USER.DATA.SET.PDS(MEMBER)");
     *
     * // Download "USER.DATA.SET" to "./path/to/file.txt"
     * await Download.dataSet(session, "USER.DATA.SET", {file: "./path/to/file.txt"});
     * ```
     */
    static dataSet(session: zowe.imperative.Session, dataSetName: string, profile: zowe.imperative.IProfile, options?: IDownloadRseOptions, mappingsFile?: string): Promise<IRestApiResponse>;
    /**
     * Retrieve all members from a PDS and save them in your local workspace
     *
     * @param {Session}          session      - RSE connection info
     * @param {string}           dataSetName  - contains the data set name
     * @param {IDownloadOptions} [options={}] - contains the options to be sent
     *
     * @returns {Promise<IZosFilesResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} data set name must be set
     * @throws {Error} When the {@link RseRestClient} throws an error
     *
     * @example
     * ```typescript
     *
     * // Download all members of "USER.DATA.SET.PDS" to "user/data/set/pds/"
     * await Download.allMembers(session, "USER.DATA.SET.PDS");
     *
     * // Download all members of "USER.DATA.SET.PDS" to "./path/to/dir/"
     * await Download.allMembers(session, "USER.DATA.SET.PDS", {directory: "./path/to/dir/"});
     * ```
     */
    static allMembers(session: zowe.imperative.Session, dataSetName: string, profile: zowe.imperative.IProfile, options?: IDownloadRseOptions, mappingsFile?: string): Promise<IRestApiResponse>;
    /**
     * Retrieve USS file content and save it in your local workspace.
     *
     * @param {Session}          session      - RSE connection info
     * @param {string}           ussFileName  - contains the USS file name and path
     * @param {IDownloadOptions} [options={}] - contains the options to be sent
     *
     * @returns {Promise<IZosFilesResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} USS file name must be set
     */
    static ussFile(session: zowe.imperative.Session, ussFileName: string, options?: IDownloadRseOptions): Promise<IRestApiResponse>;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
